searchData={"items":[{"type":"module","title":"MakeupSyntect","doc":"MakeupSyntect is an adapter for Makeup, providing syntax highlighting using the [syntect](https://docs.rs/syntect/latest/syntect/) Rust library.\n\nMore syntax definitions are included using [two-face](https://docs.rs/two-face/latest/two_face/).\n\nFor a list of supported langugages, see: `MakeupSyntect.Syntaxes`.","ref":"MakeupSyntect.html"},{"type":"function","title":"MakeupSyntect.initialize_syntaxes_from_folders/1","doc":"Initializes a syntax set from the given folders. Returns a reference that can be used\nin tokenize calls to avoid rebuilding the syntax set each time.","ref":"MakeupSyntect.html#initialize_syntaxes_from_folders/1"},{"type":"function","title":"MakeupSyntect.tokenize/2","doc":"Tokenizes the given text using syntect.","ref":"MakeupSyntect.html#tokenize/2"},{"type":"function","title":"Parameters - MakeupSyntect.tokenize/2","doc":"- text: The source code text to tokenize\n  - opts: Optional keyword list of options\n    - language: Optional language identifier (e.g. \"rust\", \"html\", \"javascript\")\n    - syntax_set: Optional syntax set resource (created via initialize_syntaxes_from_folders)","ref":"MakeupSyntect.html#tokenize/2-parameters"},{"type":"module","title":"MakeupSyntect.Syntaxes","doc":"This module provides a list of supported syntax definitions.\n\nFor usage in ExDoc, use the name in brackets as the language of the code block, e.g.\n\n````plaintext\n```http_request_and_response\nGET / HTTP/1.1\n...\n```\n````\n\n  * ARM Assembly (`arm_assembly`)\n  * ASP (`asp`)\n  * AWK (`awk`)\n  * ActionScript (`actionscript`)\n  * Ada (`ada`)\n  * Apache Conf (`apache_conf`)\n  * AppleScript (`applescript`)\n  * AsciiDoc (Asciidoctor) (`asciidoc_asciidoctor`)\n  * Assembly (x86_64) (`assembly_x86_64`)\n  * Authorized Keys (`authorized_keys`)\n  * Batch File (`batch_file`)\n  * BibTeX (`bibtex`)\n  * Bourne Again Shell (bash) (`bourne_again_shell_bash`)\n  * C (`c`)\n  * C# (`c#`)\n  * C++ (`c++`)\n  * CFML (`cfml`)\n  * CFML Script (`cfml_script`)\n  * CFML Script (Tags) (`cfml_script_tags`)\n  * CMake (`cmake`)\n  * CMake C Header (`cmake_c_header`)\n  * CMake C++ Header (`cmake_c++_header`)\n  * CMakeCache (`cmakecache`)\n  * CMakeCommands (`cmakecommands`)\n  * CSS (`css`)\n  * Cabal (`cabal`)\n  * Cargo Build Results (`cargo_build_results`)\n  * Clojure (`clojure`)\n  * CoffeeScript (`coffeescript`)\n  * Comma Separated Values (`comma_separated_values`)\n  * Command Help (`command_help`)\n  * CpuInfo (`cpuinfo`)\n  * Crontab (`crontab`)\n  * Crystal (`crystal`)\n  * D (`d`)\n  * DMD Output (`dmd_output`)\n  * Dart (`dart`)\n  * Diff (`diff`)\n  * Dockerfile (`dockerfile`)\n  * Dockerfile (with bash) (`dockerfile_with_bash`)\n  * DotENV (`dotenv`)\n  * Elixir (`elixir`)\n  * Elm (`elm`)\n  * Elm Compile Messages (`elm_compile_messages`)\n  * Elm Documentation (`elm_documentation`)\n  * Email (`email`)\n  * Erlang (`erlang`)\n  * F# (`f#`)\n  * Fish (`fish`)\n  * Fortran (Fixed Form) (`fortran_fixed_form`)\n  * Fortran (Modern) (`fortran_modern`)\n  * Fortran Namelist (`fortran_namelist`)\n  * GFortran Build Results (`gfortran_build_results`)\n  * GLSL (`glsl`)\n  * Git Attributes (`git_attributes`)\n  * Git Commit (`git_commit`)\n  * Git Common (`git_common`)\n  * Git Config (`git_config`)\n  * Git Ignore (`git_ignore`)\n  * Git Link (`git_link`)\n  * Git Log (`git_log`)\n  * Git Mailmap (`git_mailmap`)\n  * Git Rebase Todo (`git_rebase_todo`)\n  * Go (`go`)\n  * GraphQL (`graphql`)\n  * Graphviz (DOT) (`graphviz_dot`)\n  * Groff/troff (`groff/troff`)\n  * Groovy (`groovy`)\n  * HTML (`html`)\n  * HTML (ASP) (`html_asp`)\n  * HTML (EEx) (`html_eex`)\n  * HTML (Erlang) (`html_erlang`)\n  * HTML (Jinja2) (`html_jinja2`)\n  * HTML (Rails) (`html_rails`)\n  * HTML (Tcl) (`html_tcl`)\n  * HTML (Twig) (`html_twig`)\n  * HTTP Request and Response (`http_request_and_response`)\n  * Haskell (`haskell`)\n  * Highlight non-printables (`highlight_non-printables`)\n  * INI (`ini`)\n  * JQ (`jq`)\n  * JSON (`json`)\n  * JSON (Terraform) (`json_terraform`)\n  * Java (`java`)\n  * Java Properties (`java_properties`)\n  * Java Server Page (JSP) (`java_server_page_jsp`)\n  * JavaScript (`javascript`)\n  * JavaScript (Babel) (`javascript_babel`)\n  * JavaScript (Rails) (`javascript_rails`)\n  * Javadoc (`javadoc`)\n  * Jinja2 (`jinja2`)\n  * Julia (`julia`)\n  * Known Hosts (`known_hosts`)\n  * Kotlin (`kotlin`)\n  * LLVM (`llvm`)\n  * LaTeX (`latex`)\n  * LaTeX Log (`latex_log`)\n  * Lean (`lean`)\n  * Less (`less`)\n  * Lisp (`lisp`)\n  * Literate Haskell (`literate_haskell`)\n  * LiveScript (`livescript`)\n  * Lua (`lua`)\n  * MATLAB (`matlab`)\n  * Make Output (`make_output`)\n  * Makefile (`makefile`)\n  * Manpage (`manpage`)\n  * Markdown (`markdown`)\n  * MediaWiki (`mediawiki`)\n  * MediawikerPanel (`mediawikerpanel`)\n  * MemInfo (`meminfo`)\n  * MultiMarkdown (`multimarkdown`)\n  * NAnt Build File (`nant_build_file`)\n  * NSIS (`nsis`)\n  * Navigational Bar SV (`navigational_bar_sv`)\n  * Nim (`nim`)\n  * Ninja (`ninja`)\n  * Nix (`nix`)\n  * OCaml (`ocaml`)\n  * OCamllex (`ocamllex`)\n  * OCamlyacc (`ocamlyacc`)\n  * Objective-C (`objective-c`)\n  * Objective-C++ (`objective-c++`)\n  * OpenMP (Fortran) (`openmp_fortran`)\n  * PHP (`php`)\n  * PHP Source (`php_source`)\n  * Pascal (`pascal`)\n  * Perl (`perl`)\n  * Plain Text (`plain_text`)\n  * PowerShell (`powershell`)\n  * Private Key (`private_key`)\n  * Protocol Buffer (`protocol_buffer`)\n  * Protocol Buffer (TEXT) (`protocol_buffer_text`)\n  * Puppet (`puppet`)\n  * PureScript (`purescript`)\n  * Python (`python`)\n  * QML (`qml`)\n  * R (`r`)\n  * R Console (`r_console`)\n  * Racket (`racket`)\n  * Rd (R Documentation) (`rd_r_documentation`)\n  * Rego (`rego`)\n  * Regular Expression (`regular_expression`)\n  * Regular Expressions (Elixir) (`regular_expressions_elixir`)\n  * Regular Expressions (Javascript) (`regular_expressions_javascript`)\n  * Regular Expressions (PHP) (`regular_expressions_php`)\n  * Regular Expressions (Python) (`regular_expressions_python`)\n  * Requirements.txt (`requirements.txt`)\n  * Robot Framework (`robot_framework`)\n  * Ruby (`ruby`)\n  * Ruby Haml (`ruby_haml`)\n  * Ruby Slim (`ruby_slim`)\n  * Ruby on Rails (`ruby_on_rails`)\n  * Rust (`rust`)\n  * SCSS (`scss`)\n  * SML (`sml`)\n  * SQL (`sql`)\n  * SQL (Rails) (`sql_rails`)\n  * SSH Common (`ssh_common`)\n  * SSH Config (`ssh_config`)\n  * SSH Crypto (`ssh_crypto`)\n  * SSHD Config (`sshd_config`)\n  * Salt State (SLS) (`salt_state_sls`)\n  * Sass (`sass`)\n  * Scala (`scala`)\n  * Shell-Unix-Generic (`shell-unix-generic`)\n  * Solidity (`solidity`)\n  * Strace (`strace`)\n  * Stylus (`stylus`)\n  * Svelte (`svelte`)\n  * Swift (`swift`)\n  * SystemVerilog (`systemverilog`)\n  * TOML (`toml`)\n  * Tcl (`tcl`)\n  * TeX (`tex`)\n  * Terraform (`terraform`)\n  * TestBox (`testbox`)\n  * Textile (`textile`)\n  * Todo.txt (`todo.txt`)\n  * TypeScript (`typescript`)\n  * TypeScriptReact (`typescriptreact`)\n  * Verilog (`verilog`)\n  * VimHelp (`vimhelp`)\n  * VimL (`viml`)\n  * Vue Component (`vue_component`)\n  * Vyper (`vyper`)\n  * WGSL (`wgsl`)\n  * XML (`xml`)\n  * YAML (`yaml`)\n  * Zig (`zig`)\n  * camlp4 (`camlp4`)\n  * commands-builtin-shell-bash (`commands-builtin-shell-bash`)\n  * fstab (`fstab`)\n  * gnuplot (`gnuplot`)\n  * group (`group`)\n  * hosts (`hosts`)\n  * jsonnet (`jsonnet`)\n  * log (`log`)\n  * nginx (`nginx`)\n  * orgmode (`orgmode`)\n  * passwd (`passwd`)\n  * reStructuredText (`restructuredtext`)\n  * resolv (`resolv`)\n  * syslog (`syslog`)\n  * varlink (`varlink`)","ref":"MakeupSyntect.Syntaxes.html"},{"type":"function","title":"MakeupSyntect.Syntaxes.all/0","doc":"Returns a list of all supported syntax definitions.\n\nReturns a list of maps containing:\n  - name: The name of the syntax (e.g. \"HTML\", \"JavaScript\")\n  - file_extensions: List of file extensions (e.g. [\"html\", \"htm\"])","ref":"MakeupSyntect.Syntaxes.html#all/0"},{"type":"function","title":"Example - MakeupSyntect.Syntaxes.all/0","doc":"iex> MakeupSyntect.Syntaxes.all()\n    [\n      %{name: \"Plain Text\", extensions: [\"txt\"], codeblock_name: \"plain_text\"},\n      %{name: \"ASP\", extensions: [\"asa\"], codeblock_name: \"asp\"},\n      %{name: \"HTML (ASP)\", extensions: [\"asp\"], codeblock_name: \"html_asp\"},\n      %{name: \"ActionScript\", extensions: [\"as\"], codeblock_name: \"actionscript\"}\n      ...\n    ]","ref":"MakeupSyntect.Syntaxes.html#all/0-example"},{"type":"extras","title":"assembly","doc":"","ref":"assembly.html"},{"type":"extras","title":"x86_64 Assembly Code Example - assembly","doc":"```assembly_x86_64\n; Comprehensive x86_64 Assembly Demo\n; Demonstrates various syntax features, directives, and instructions\n\n; Section declarations\nsection .data\n    ; Various data declarations\n    msg_hello    db      \"Hello, World!\", 0x0A, 0    ; String with newline and null terminator\n    num1         dq      42                          ; 64-bit integer\n    pi           dd      3.14159                     ; 32-bit float\n    array        times 5 dd 0                        ; Array of 5 32-bit zeros\n    flags        db      0b10101010                  ; Binary notation\n    hex_val      dq      0xDEADBEEF                 ; Hexadecimal notation\n\nsection .bss\n    ; Uninitialized data\n    buffer       resb    64                          ; Reserve 64 bytes\n    big_array    resq    100                        ; Reserve space for 100 64-bit values\n\nsection .text\n    global _start                                    ; Entry point declaration\n\n; Constants and macros\n%define STDOUT      1\n%define SYS_WRITE   1\n%define SYS_EXIT    60\n\n; Macro definition\n%macro print_string 2\n    mov     rax, SYS_WRITE\n    mov     rdi, STDOUT\n    mov     rsi, %1\n    mov     rdx, %2\n    syscall\n%endmacro\n\n_start:\n    ; Function prologue\n    push    rbp\n    mov     rbp, rsp\n\n    ; Basic arithmetic\n    mov     rax, 10\n    add     rax, 5                                  ; Addition\n    sub     rax, 3                                  ; Subtraction\n    imul    rax, 2                                  ; Multiplication\n\n    ; Bitwise operations\n    mov     rbx, 0xFF\n    and     rbx, 0xF0                              ; AND operation\n    or      rbx, 0x0F                              ; OR operation\n    xor     rbx, rbx                               ; Clear register\n\n    ; Conditional execution\n    cmp     rax, 20\n    je      equal_twenty                           ; Jump if equal\n    jmp     not_twenty                             ; Unconditional jump\n\nequal_twenty:\n    mov     rcx, 1\n\nnot_twenty:\n    ; Loop example\n    mov     rcx, 5                                 ; Counter\nloop_start:\n    push    rcx                                    ; Save counter\n    ; ... loop body ...\n    pop     rcx                                    ; Restore counter\n    dec     rcx\n    jnz     loop_start                            ; Jump if not zero\n\n    ; Stack operations\n    push    qword [num1]                          ; Push value to stack\n    pop     rax                                   ; Pop value from stack\n\n    ; Memory addressing modes\n    mov     rax, [array]                          ; Direct addressing\n    mov     rbx, [array + 8]                      ; Base + displacement\n    mov     rcx, [array + rax*4]                  ; Base + index*scale\n\n    ; SIMD instruction example (if supported)\n    movdqu  xmm0, [array]                         ; Load unaligned 128-bit data\n\n    ; System call example\n    print_string msg_hello, 13                    ; Using our macro\n\n    ; Function epilogue and exit\n    mov     rsp, rbp\n    pop     rbp\n\n    mov     rax, SYS_EXIT                         ; Exit syscall\n    xor     rdi, rdi                              ; Return 0\n    syscall\n\n; Local function example\nlocal_func:\n    push    rbp\n    mov     rbp, rsp\n    ; Function body\n    leave\n    ret\n```","ref":"assembly.html#x86_64-assembly-code-example"},{"type":"extras","title":"bash","doc":"","ref":"bash.html"},{"type":"extras","title":"Bash Code Example - bash","doc":"```bourne_again_shell_bash\n#!/bin/bash\n\n# Demo script showcasing various Bash features\nset -euo pipefail  # Strict mode\n\n# Variables and string manipulation\nNAME=\"Bash Demo\"\nVERSION=1.0\nCURRENT_DATE=$(date +%Y-%m-%d)\ndeclare -A HASH_MAP=([key1]=\"value1\" [key2]=\"value2\")\ndeclare -a ARRAY=(1 2 3 4 5)\n\n# Functions\nfunction print_header() {\n    local title=\"$1\"\n    echo \"=== ${title} ===\"\n}\n\n# Error handling function\nerror_handler() {\n    local line_num=$1\n    echo \"Error occurred in script at line: ${line_num}\"\n}\n\ntrap 'error_handler ${LINENO}' ERR\n\n# Demonstrate string operations\nprint_header \"String Operations\"\nSTRING=\"Hello, World!\"\necho \"Original: ${STRING}\"\necho \"Length: ${#STRING}\"\necho \"Substring: ${STRING:0:5}\"\necho \"Uppercase: ${STRING^^}\"\necho \"Lowercase: ${STRING,,}\"\n\n# Arithmetic operations\nprint_header \"Arithmetic\"\nA=5\nB=3\necho \"$A + $B = $((A + B))\"\necho \"$A * $B = $((A * B))\"\necho \"Power: $((A ** 2))\"\n\n# Control structures\nprint_header \"Control Structures\"\n\n# If-else\nif [[ $A -gt $B ]]; then\n    echo \"$A is greater than $B\"\nelif [[ $A -eq $B ]]; then\n    echo \"$A equals $B\"\nelse\n    echo \"$A is less than $B\"\nfi\n\n# Case statement\nFRUIT=\"apple\"\ncase $FRUIT in\n    \"apple\")\n        echo \"Selected fruit is apple\"\n        ;;\n    \"banana\"|\"orange\")\n        echo \"Selected fruit is banana or orange\"\n        ;;\n    *)\n        echo \"Unknown fruit\"\n        ;;\nesac\n\n# Loops\nprint_header \"Loops\"\n\n# For loop\nfor i in \"${ARRAY[@]}\"; do\n    echo \"Array element: $i\"\ndone\n\n# While loop with counter\ncounter=0\nwhile [[ $counter -lt 3 ]]; do\n    echo \"Counter: $counter\"\n    ((counter++))\ndone\n\n# Until loop\nuntil [[ $counter -eq 0 ]]; do\n    echo \"Counting down: $counter\"\n    ((counter--))\ndone\n\n# File operations\nprint_header \"File Operations\"\nTEST_FILE=\"/tmp/test.txt\"\n\n# Write to file\ncat <  \"$TEST_FILE\"\nLine 1\nLine 2\nLine 3\nEOF\n\n# Read from file\nwhile IFS= read -r line; do\n    echo \"Read: $line\"\ndone < \"$TEST_FILE\"\n\n# Parameter expansion\nprint_header \"Parameter Expansion\"\nUNSET_VAR=\"\"\necho \"Default value: ${UNSET_VAR:-default}\"\necho \"Alternate value: ${NAME:+alternate}\"\necho \"Substring removal: ${STRING#Hello,}\"\necho \"Pattern matching: ${STRING/World/Bash}\"\n\n# Process substitution and command substitution\nprint_header \"Process & Command Substitution\"\necho \"Files in current directory: $(ls | wc -l)\"\ndiff <(sort \"$TEST_FILE\") <(sort -r \"$TEST_FILE\")\n\n# Associative array operations\nprint_header \"Associative Array\"\nfor key in \"${!HASH_MAP[@]}\"; do\n    echo \"Key: $key, Value: ${HASH_MAP[$key]}\"\ndone\n\n# Cleanup\nrm -f \"$TEST_FILE\"\n\n# Exit status\nprint_header \"Exit Status\"\ntrue\necho \"Last command status: $?\"\nfalse || echo \"Command failed but script continues\"\n\n# Here document with parameter expansion\nprint_header \"Here Document\"\ncat << EOT\nScript: $NAME\nVersion: $VERSION\nDate: $CURRENT_DATE\nEOT\n\nexit 0\n```","ref":"bash.html#bash-code-example"},{"type":"extras","title":"batch","doc":"","ref":"batch.html"},{"type":"extras","title":"Windows Batch Example - batch","doc":"```batch_file\n@echo off\nsetlocal EnableDelayedExpansion\n\n:: This is a comment\nREM This is another way to comment\n\necho ====================================\necho Windows Batch File Syntax Demo\necho ====================================\n\n:: Variables and user input\nset \"name=World\"\nset /p \"userInput=Please enter your name: \"\nif not \"%userInput%\"==\"\" set \"name=%userInput%\"\n\n:: Basic output and variables\necho.\necho Hello, %name%!\necho Current directory: %CD%\necho Batch file name: %~nx0\necho Full path: %~f0\n\n:: Environment variables\necho.\necho System Drive: %SystemDrive%\necho Program Files: %ProgramFiles%\necho User Profile: %USERPROFILE%\n\n:: Arithmetic operations\nset /a num1=5\nset /a num2=3\nset /a sum=%num1%+%num2%\nset /a product=%num1%*%num2%\necho.\necho Basic Math:\necho %num1% + %num2% = %sum%\necho %num1% * %num2% = %product%\n\n:: Conditional statements\necho.\necho Conditional Examples:\nif %num1% GTR %num2% (\n    echo %num1% is greater than %num2%\n) else (\n    echo %num1% is not greater than %num2%\n)\n\n:: Loop examples\necho.\necho For Loop Example:\nfor %%i in (1 2 3 4 5) do (\n    echo Number: %%i\n)\n\necho.\necho Directory Loop Example:\nfor /d %%d in (\"%SystemDrive%\\*\") do (\n    echo Found directory: %%d\n)\n\n:: Function/Label demonstration\ncall :MyFunction \"Hello from function!\"\ngoto :SkipFunction\n\n:MyFunction\necho.\necho Function Demo:\necho Parameter received: %~1\nexit /b\n\n:SkipFunction\n\n:: Error handling\necho.\necho Error Handling Demo:\ndir /x nonexistent.file 2>nul\nif errorlevel 1 (\n    echo File not found error detected\n)\n\n:: Delayed expansion example\nset \"counter=1\"\nfor %%a in (A B C) do (\n    set /a \"counter+=1\"\n    echo Counter is: !counter! for %%a\n)\n\n:: Choice command\necho.\necho Choice Command Demo:\nchoice /c YN /m \"Do you want to continue\"\nif errorlevel 2 goto :EndDemo\nif errorlevel 1 echo You selected Yes\n\n:: Working with files\necho.\necho File Operations Demo:\necho Creating temporary file...\necho Test content > temp.txt\ntype temp.txt\ndel temp.txt\n\n:: Command nesting and piping\necho.\necho Command Nesting Demo:\ndir | find \"DIR\" > nul && echo Directories found\n\n:: Random number generation\nset /a \"random_num=%random% %% 100 + 1\"\necho.\necho Random number between 1 and 100: %random_num%\n\n:EndDemo\necho.\necho ====================================\necho Demo Complete\necho ====================================\n\nendlocal\npause\n```","ref":"batch.html#windows-batch-example"},{"type":"extras","title":"css","doc":"","ref":"css.html"},{"type":"extras","title":"CSS Code Example - css","doc":"```css\n/* Typography Variables */\n:root {\n  --font-primary: 'Helvetica Neue', sans-serif;\n  --font-secondary: Georgia, serif;\n  --font-size-base: 16px;\n  --line-height: 1.5;\n\n  /* Color Scheme */\n  --color-primary: #007bff;\n  --color-secondary: #6c757d;\n  --color-success: #28a745;\n  --color-error: rgb(220, 53, 69);\n  --color-warning: hsl(45, 100%, 51%);\n\n  /* Spacing */\n  --spacing-unit: 8px;\n  --spacing-large: calc(var(--spacing-unit) * 2);\n  --spacing-small: calc(var(--spacing-unit) * 0.5);\n\n  /* Borders */\n  --border-radius: 4px;\n  --border-width: 1px;\n}\n\n/* Media Queries and Feature Queries */\n@media screen and (min-width: 768px) {\n  :root {\n    --font-size-base: 18px;\n  }\n}\n\n@supports (display: grid) {\n  .grid-layout {\n    display: grid;\n    grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));\n    gap: var(--spacing-large);\n  }\n}\n\n/* Animations and Keyframes */\n@keyframes fadeIn {\n  from {\n    opacity: 0;\n    transform: translateY(-20px);\n  }\n\n  to {\n    opacity: 1;\n    transform: translateY(0);\n  }\n}\n\n/* Complex Selectors */\n.container > .header {\n  font-family: var(--font-primary);\n  font-size: calc(var(--font-size-base) * 1.5);\n  color: var(--color-primary);\n  background-image: url(https://example.com/image.jpg);\n}\n\n#main-content {\n  padding: var(--spacing-large);\n  background-color: white;\n  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);\n}\n\n/* Pseudo-classes and Pseudo-elements */\n.button:hover,\n.button:focus {\n  background-color: var(--color-secondary);\n  transform: translateY(-1px);\n  transition: all 0.3s ease;\n}\n\n.card::before {\n  content: '';\n  display: block;\n  padding-top: 56.25%; /* 16:9 Aspect Ratio */\n}\n\n/* Attribute Selectors */\ninput[type=\"text\"],\ninput[type=\"email\"] {\n  border: var(--border-width) solid var(--color-secondary);\n  border-radius: var(--border-radius);\n  padding: var(--spacing-unit);\n}\n\nbutton[disabled] {\n  opacity: 0.5;\n  cursor: not-allowed;\n}\n\n/* Complex Properties */\n.gradient-background {\n  background-image: linear-gradient(\n    45deg,\n    var(--color-primary) 0%,\n    var(--color-secondary) 100%\n  );\n}\n\n.flex-container {\n  display: flex;\n  flex-direction: column;\n  gap: clamp(1rem, 2vw, 2rem);\n}\n\n/* Named Colors and Units */\n.color-examples {\n  color: darkslateblue;\n  background-color: aliceblue;\n  border: 2px solid cornflowerblue;\n}\n\n.unit-examples {\n  /* Absolute Units */\n  width: 100px;\n  margin: 1in;\n  border: 0.5mm solid black;\n\n  /* Relative Units */\n  padding: 1.5rem;\n  font-size: 1.2em;\n  line-height: 1.6;\n\n  /* Viewport Units */\n  height: 50vh;\n  max-width: 90vw;\n\n  /* Calculation */\n  margin-top: calc(2rem + 20px);\n}\n\n/* Function Usage */\n.advanced-properties {\n  /* Color Functions */\n  color: rgb(33, 37, 41);\n  background-color: rgba(255, 255, 255, 0.9);\n  border-color: hsl(210, 50%, 50%);\n  outline-color: hsla(210, 50%, 50%, 0.5);\n\n  /* Transform Functions */\n  transform: translate3d(0, 10px, 0) rotate(45deg) scale(1.1);\n\n  /* Filter Functions */\n  filter: brightness(1.2) contrast(1.1) blur(2px);\n\n  /* Modern Color Functions */\n  color: color-mix(in srgb, var(--color-primary) 50%, var(--color-secondary));\n}\n\n/* Custom Media Queries */\n@custom-media --mobile (max-width: 768px);\n@custom-media --tablet (min-width: 769px) and (max-width: 1024px);\n@custom-media --desktop (min-width: 1025px);\n\n@media (--mobile) {\n  .responsive-element {\n    font-size: 14px;\n    padding: 0.5rem;\n  }\n}\n\n/* Layer Declarations */\n@layer base, components, utilities;\n\n@layer base {\n  /* Base styles */\n  body {\n    margin: 0;\n    font-family: var(--font-primary);\n    line-height: var(--line-height);\n  }\n}\n\n@layer components {\n  /* Component styles */\n  .card {\n    border-radius: var(--border-radius);\n    padding: var(--spacing-unit);\n  }\n}\n\n/* Container Queries */\n@container (min-width: 400px) {\n  .container-query-card {\n    display: grid;\n    grid-template-columns: 2fr 1fr;\n  }\n}\n\n/* Support Queries */\n@supports (aspect-ratio: 16/9) {\n  .video-container {\n    aspect-ratio: 16/9;\n  }\n}\n\n/* Nest Rules (using PostCSS or other preprocessors) */\n.article {\n  & h1 {\n    font-size: 2rem;\n\n    &:first-child {\n      margin-top: 0;\n    }\n  }\n\n  & p {\n    margin-bottom: var(--spacing-unit);\n  }\n}\n```","ref":"css.html#css-code-example"},{"type":"extras","title":"elixir","doc":"","ref":"elixir.html"},{"type":"extras","title":"Elixir Code Example - elixir","doc":"```elixir\ndefmodule SyntaxDemo do\n  @moduledoc \"\"\"\n  A demonstration module showcasing various Elixir syntax features.\n  \"\"\"\n\n  # Module attribute definition\n  @greeting \"Hello\"\n  @constant_value 42\n\n  # Type specifications\n  @type coordinates :: {number, number}\n  @type user :: %{name: String.t(), age: non_neg_integer()}\n\n  # Struct definition\n  defstruct name: \"\", age: 0, roles: []\n\n  # Guard clause definition\n  defguard is_valid_age?(age) when is_integer(age) and age >= 0\n\n  # Function with pattern matching and guards\n  def process_age(age) when is_valid_age?(age) do\n    case age do\n      0 -> \"Newborn\"\n      age when age < 13 -> \"Child\"\n      age when age < 20 -> \"Teenager\"\n      _ -> \"Adult\"\n    end\n  end\n\n  # Function with default parameters\n  def greet(name, greeting \\\\ @greeting) do\n    \"#{greeting}, #{name}!\"\n  end\n\n  # Private function\n  defp double(x), do: x * 2\n\n  # List comprehension and pattern matching\n  def process_pairs(list) do\n    for {a, b} <- list,\n        a > 0,\n        do: {a, double(b)}\n  end\n\n  # Pipeline operator example\n  def transform_string(input) do\n    input\n    |> String.trim()\n    |> String.upcase()\n    |> String.split()\n    |> Enum.join(\"-\")\n  end\n\n  # Pattern matching in function heads\n  def handle_result({:ok, value}), do: \"Success: #{value}\"\n  def handle_result({:error, reason}), do: \"Error: #{reason}\"\n\n  # Working with maps\n  def update_user(user = %{name: name}) do\n    %{user | name: String.upcase(name)}\n  end\n\n  # Using with for complex pattern matching\n  def process_data(data) do\n    with {:ok, number} <- parse_number(data),\n         doubled when doubled < 100 <- double(number) do\n      {:ok, doubled}\n    else\n      {:error, reason} -> {:error, reason}\n      _ -> {:error, \"Number too large\"}\n    end\n  end\n\n  # Private helper function\n  defp parse_number(str) when is_binary(str) do\n    case Integer.parse(str) do\n      {num, \"\"} -> {:ok, num}\n      _ -> {:error, \"Invalid number\"}\n    end\n  end\n\n  # Anonymous functions\n  def get_math_functions do\n    add = &(&1 + &2)\n    multiply = fn x, y -> x * y end\n\n    [add, multiply]\n  end\n\n  # Using protocols\n  defimpl String.Chars, for: SyntaxDemo do\n    def to_string(%SyntaxDemo{name: name}) do\n      \"SyntaxDemo: #{name}\"\n    end\n  end\n\n  # Macro usage example\n  require Logger\n  def log_info(message) do\n    Logger.info(\"#{@greeting}: #{message}\")\n  end\n\n  # Using try-rescue\n  def safe_divide(a, b) do\n    try do\n      a / b\n    rescue\n      ArithmeticError -> {:error, \"Division by zero\"}\n    else\n      result -> {:ok, result}\n    end\n  end\n\n  # Comprehension with multiple generators\n  def matrix_combination do\n    for x <- 1..3,\n        y <- 1..3,\n        x != y,\n        do: {x, y}\n  end\n\n  # Pattern matching with bitstrings\n  def extract_bytes(< >) do\n    {first_byte, rest}\n  end\n\n  # Using receive for processes\n  def start_process do\n    spawn(fn -> process_loop() end)\n  end\n\n  defp process_loop do\n    receive do\n      {:message, content} -> \n        IO.puts(\"Received: #{content}\")\n        process_loop()\n      :stop -> \n        :ok\n    end\n  end\nend\n\n# Example usage of protocols\ndefprotocol Drawable do\n  @doc \"Defines how to draw an entity\"\n  def draw(entity)\nend\n\n# Example of using behaviors\ndefmodule CustomServer do\n  @behaviour GenServer\n\n  def init(args), do: {:ok, args}\n  def handle_call(_msg, _from, state), do: {:reply, :ok, state}\n  def handle_cast(_msg, state), do: {:noreply, state}\nend\n```","ref":"elixir.html#elixir-code-example"},{"type":"extras","title":"html","doc":"","ref":"html.html"},{"type":"extras","title":"HTML Code Example - html","doc":"```html\n<!DOCTYPE html>\n \n\n \n   Page Title \n \n\n \n\n   This is a Heading \n\n   This is a Subheading \n\n   \n    This  is  a paragraph.\n    It contains  several  sentences \n\n \n\n \n```","ref":"html.html#html-code-example"},{"type":"extras","title":"With inline CSS and JavaScript - html","doc":"```html\n<!DOCTYPE html>\n \n   \n     \n     HTML Syntax Demo \n     \n      /* CSS demonstrates different selectors and properties */\n      body {\n        font-family: Arial, sans-serif;\n        line-height: 1.6;\n        margin: 2rem;\n      }\n\n      .container {\n        max-width: 800px;\n        margin: 0 auto;\n        padding: 20px;\n        border: 1px solid #ddd;\n      }\n\n      /* Descendant selector */\n      .container h1 {\n        color: #2c3e50;\n      }\n\n      /* Pseudo-class */\n      a:hover {\n        color: #e74c3c;\n      }\n\n      /* Attribute selector */\n      input[type=\"text\"] {\n        padding: 8px;\n        border: 2px solid #3498db;\n        border-radius: 4px;\n      }\n\n      /* Combinators */\n      h2+p {\n        font-style: italic;\n      }\n\n      /* Media query */\n      @media (max-width: 600px) {\n        .container {\n          padding: 10px;\n        }\n      }\n     \n   \n   \n     \n      <!-- Headings -->\n       HTML Syntax Features \n\n      <!-- Text formatting -->\n       This is a  bold text  and this is an  italicized text . \n       You can also use  highlighted text  and  inline code . \n\n      <!-- Lists -->\n       Unordered List \n       \n         First item \n         Second item\n           \n             Nested item \n           \n         \n       \n\n      <!-- Table -->\n       Table Example \n       \n         \n           \n             Header 1 \n             Header 2 \n           \n         \n         \n           \n             Data 1 \n             Data 2 \n           \n         \n       \n\n      <!-- Form -->\n       Form Elements \n       \n         \n           Name: \n           \n         \n         \n           \n              Subscribe to newsletter\n           \n         \n         Submit \n       \n\n      <!-- Interactive element -->\n       Interactive Demo \n       Change Heading Color \n     \n\n     \n      // JavaScript demonstrates various features\n\n      // Event handling\n      function handleSubmit(event) {\n        event.preventDefault();\n        const formData = new FormData(event.target);\n        const name = formData.get('name');\n        alert(`Hello, ${name}!`);\n      }\n\n      // DOM manipulation\n      function changeColor() {\n        const heading = document.querySelector('h1');\n        const randomColor = '#' + Math.floor(Math.random() * 16777215).toString(16);\n        heading.style.color = randomColor;\n      }\n\n      // Array methods and arrow functions\n      const numbers = [1, 2, 3, 4, 5];\n      const doubled = numbers.map(num => num * 2);\n      console.log('Doubled numbers:', doubled);\n\n      // Async/await example\n      async function fetchData() {\n        try {\n          const response = await fetch('https://api.example.com/data');\n          const data = await response.json();\n          console.log(data);\n        } catch (error) {\n          console.error('Error:', error);\n        }\n      }\n\n      // Class definition\n      class Counter {\n        constructor() {\n          this.count = 0;\n        }\n\n        increment() {\n          this.count++;\n          return this.count;\n        }\n      }\n\n      // Event listener\n      document.addEventListener('DOMContentLoaded', () => {\n        console.log('Document loaded!');\n      });\n     \n   \n \n```","ref":"html.html#with-inline-css-and-javascript"},{"type":"extras","title":"HEEx - html","doc":"We tokenize HEEx components and slots as tag names. This is important in order to use\n`makeup_syntect` with `makeup_eex`'s HEEx lexer.\n\n```html\n<.header>\n  <:top_slot>Foo</:top_slot>\n  <.button>Click</.button>\n   \n   We support interpolation with {@name} and <%= @name %>. \n   \n    console.log(\"Hello World\");\n   \n</.header>\n```","ref":"html.html#heex"},{"type":"extras","title":"http","doc":"","ref":"http.html"},{"type":"extras","title":"HTTP Example - http","doc":"```http_request_and_response\n# HTTP Request\nGET /api/users/123 HTTP/1.1\nHost: api.example.com\nAccept: application/json\nAuthorization: Bearer eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9...\nUser-Agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64)\nCache-Control: no-cache\nConnection: keep-alive\n\n# HTTP Response\nHTTP/1.1 200 OK\nDate: Wed, 05 Feb 2025 10:30:15 GMT\nContent-Type: application/json\nContent-Length: 157\nCache-Control: private, max-age=3600\nX-Request-ID: f28b9a6d-c2a1-4d9b-9c62-764f234f1234\nAccess-Control-Allow-Origin: *\n\n{\n    \"id\": 123,\n    \"name\": \"John Doe\",\n    \"email\": \"john.doe@example.com\",\n    \"created_at\": \"2025-01-15T08:00:00Z\",\n    \"status\": \"active\"\n}\n```","ref":"http.html#http-example"},{"type":"extras","title":"java","doc":"","ref":"java.html"},{"type":"extras","title":"Java Code Example - java","doc":"```java\n// Package declaration\npackage com.example.demo;\n\n// Import statements\nimport java.util.*;\nimport java.util.stream.Collectors;\nimport java.util.concurrent.CompletableFuture;\nimport java.io.Serializable;\n\n// Annotation example\n@FunctionalInterface\ninterface Calculator {\n    int calculate(int x, int y);\n}\n\n// Main class demonstration\npublic class JavaSyntaxDemo  implements Serializable {\n    // Static and final variables\n    private static final long serialVersionUID = 1L;\n    public static final double PI = 3.14159;\n\n    // Instance variables with different access modifiers\n    private String privateField;\n    protected int protectedField;\n    public boolean publicField;\n\n    // Generic type field\n    private T genericField;\n\n    // Enum declaration\n    public enum Status {\n        ACTIVE, INACTIVE, PENDING\n    }\n\n    // Static nested class\n    static class NestedClass {\n        void nestedMethod() {\n            System.out.println(\"Inside nested class\");\n        }\n    }\n\n    // Constructor\n    public JavaSyntaxDemo(T genericField) {\n        this.genericField = genericField;\n    }\n\n    // Method with varargs\n    public static   void printAll(E... elements) {\n        for (E element : elements) {\n            System.out.println(element);\n        }\n    }\n\n    // Generic method\n    public   void genericMethod(U parameter) {\n        System.out.println(\"Generic parameter: \" + parameter);\n    }\n\n    // Method demonstrating exception handling\n    public void exceptionDemo() throws IllegalArgumentException {\n        try {\n            throw new IllegalArgumentException(\"Demo exception\");\n        } catch (Exception e) {\n            System.err.println(\"Caught exception: \" + e.getMessage());\n        } finally {\n            System.out.println(\"Finally block executed\");\n        }\n    }\n\n    // Lambda expression and Stream API demonstration\n    public void streamDemo() {\n        List  numbers = Arrays.asList(1, 2, 3, 4, 5);\n\n        // Stream operations\n        List  doubled = numbers.stream()\n            .filter(n -> n % 2 == 0)\n            .map(n -> n * 2)\n            .collect(Collectors.toList());\n    }\n\n    // Async programming with CompletableFuture\n    public CompletableFuture  asyncDemo() {\n        return CompletableFuture.supplyAsync(() -> \"Async result\");\n    }\n\n    // Method with synchronized block\n    public synchronized void synchronizedMethod() {\n        synchronized(this) {\n            System.out.println(\"Thread-safe operation\");\n        }\n    }\n\n    // Main method\n    public static void main(String[] args) {\n        // Object creation\n        JavaSyntaxDemo  demo = new JavaSyntaxDemo<>(\"Hello\");\n\n        // Array declaration and initialization\n        int[] array = new int[]{1, 2, 3};\n\n        // Enhanced for loop\n        for (int item : array) {\n            System.out.println(item);\n        }\n\n        // Lambda expression\n        Calculator add = (x, y) -> x + y;\n\n        // Switch expression (Java 14+)\n        Status status = Status.ACTIVE;\n        String message = switch (status) {\n            case ACTIVE -> \"Active status\";\n            case INACTIVE -> \"Inactive status\";\n            case PENDING -> \"Pending status\";\n        };\n\n        // Try-with-resources\n        try (Scanner scanner = new Scanner(System.in)) {\n            System.out.println(\"Enter something:\");\n            String input = scanner.nextLine();\n        }\n\n        // Record declaration (Java 16+)\n        record Point(int x, int y) {}\n        Point point = new Point(10, 20);\n\n        // Text block (Java 15+)\n        String textBlock = \"\"\"\n            This is a text block.\n            It can span multiple lines\n            with proper indentation.\n            \"\"\";\n    }\n}\n```","ref":"java.html#java-code-example"},{"type":"extras","title":"javascript","doc":"","ref":"javascript.html"},{"type":"extras","title":"JavaScript Code Example - javascript","doc":"```javascript\n#!/usr/bin/env node\n// This is a single-line comment\n\n/* This is a multi-line comment\n   showing various JavaScript features */\n\n// Module imports\nimport defaultExport from \"module-name\";\nimport * as name from \"module-name\";\nimport { export1 } from \"module-name\";\nimport { export1 as alias1 } from \"module-name\";\nimport { default as alias } from \"module-name\";\nimport { export1, export2 } from \"module-name\";\nimport { export1, export2 as alias2 } from \"module-name\";\nimport { \"string name\" as alias } from \"module-name\";\nimport defaultExport, { export1 } from \"module-name\";\nimport defaultExport, * as name from \"module-name\";\nimport \"module-name\";\n\n// Import attributes\nimport { names } from \"module-name\" with {};\nimport { names } from \"module-name\" with { key: \"data\" };\nimport { names } from \"module-name\" with { key: \"data\", key2: \"data2\" };\nimport { names } from \"module-name\" with { key: \"data\", key2: \"data2\", keyN: \"dataN\" };\n\nexport { names } from \"module-name\" with {};\nexport { names } from \"module-name\" with { key: \"data\" };\nexport { names } from \"module-name\" with { key: \"data\", key2: \"data2\" };\nexport { names } from \"module-name\" with { key: \"data\", key2: \"data2\", keyN: \"dataN\" };\n\n// Numbers\nconst integers = 42;\nconst float = 3.14159;\nconst hex = 0xFF;\nconst binary = 0b1010;\nconst octal = 0o777;\nconst bigInt = 9007199254740991n;\nconst scientific = 1.23e-4;\n\n// Strings\nconst singleQuoted = 'Hello World';\nconst doubleQuoted = \"Hello World\";\nconst escapedString = 'It\\'s a beautiful day\\nNew line\\tTabbed';\nconst templateLiteral = `Current value: ${integers + float + {}}\n  Multi-line string\n  With interpolation: ${hex}`;\n\n// Symbols\nconst symbol = Symbol('description');\nconst uniqueSymbol = Symbol.for('global');\n\n// Arrays and destructuring\nconst array = [1, 2, 3, 'mixed', true, null];\nconst [first, second, ...rest] = array;\nconst matrix = [[1, 2], [3, 4]];\n\n// Objects and destructuring\nconst person = {\n  name: 'John',\n  age: 30,\n  'special-key': true,\n  method() {\n    return this.name;\n  },\n  get fullName() {\n    return `${this.name} Doe`;\n  },\n  set fullName(value) {\n    this.name = value;\n  }\n};\n\nconst { name, age: personAge } = person;\n\n// Classes\nclass Animal {\n  #privateField = 'hidden';\n  static species = 'Unknown';\n\n  constructor(name) {\n    this.name = name;\n  }\n\n  static createDog() {\n    return new this('Dog');\n  }\n\n  makeSound() {\n    console.log('Generic animal sound');\n  }\n}\n\nclass Dog extends Animal {\n  constructor(name, breed) {\n    super(name);\n    this.breed = breed;\n  }\n\n  makeSound() {\n    console.log('Woof!');\n  }\n}\n\n// Functions\nfunction normalFunction(a, b = 1) {\n  return a + b;\n}\n\nconst arrowFunction = (x, y) => {\n  return x * y;\n};\n\nconst shortArrow = x => x * 2;\n\nasync function asyncFunction() {\n  try {\n    const response = await fetch('https://api.example.com');\n    const data = await response.json();\n    return data;\n  } catch (error) {\n    console.error(error);\n    throw new Error('Failed to fetch');\n  }\n}\n\n// Control structures\nif (array.length > 0) {\n  console.log('Array has elements');\n} else if (array.length === 0) {\n  console.log('Array is empty');\n} else {\n  console.log('Impossible condition');\n}\n\nfor (let i = 0; i   0.5) {\n      resolve('Success!');\n    } else {\n      reject(new Error('Failed!'));\n    }\n  }, 1000);\n});\n\npromise\n  .then(result => console.log(result))\n  .catch(error => console.error(error))\n  .finally(() => console.log('Cleanup'));\n\n// Nullish coalescing and optional chaining\nconst nullish = null ?? 'default';\nconst chainedValue = person?.address?.street;\n\n// Logical operators and assignments\nconst logicalAnd = true && 'value';\nconst logicalOr = false || 'fallback';\nlet value = 0;\nvalue &&= 5;\nvalue ||= 10;\nvalue ??= 15;\n\n// Bitwise operations\nconst bitwiseAnd = 5 & 3;\nconst bitwiseOr = 5 | 3;\nconst bitwiseXor = 5 ^ 3;\nconst leftShift = 5 << 1;\nconst rightShift = 5 >> 1;\nconst zeroFillRightShift = -5 >>> 1;\n\n// DOM manipulation (if in browser)\nif (typeof window !== 'undefined') {\n  const element = document.getElementById('example');\n  element?.addEventListener('click', (event) => {\n    event.preventDefault();\n    element.innerHTML = `Clicked at ${event.clientX}, ${event.clientY}`;\n  });\n}\n\n// Exporting declarations\nexport let name1, name2/*, … */; // also var\nexport const name1 = 1, name2 = 2/*, … */; // also var, let\nexport function functionName() { /* … */ }\nexport class ClassName { /* … */ }\nexport function* generatorFunctionName() { /* … */ }\nexport const { name1, name2: bar } = o;\nexport const [ name1, name2 ] = array;\n\n// Export list\nexport { name1, name2, name3 };\nexport { variable1 as name1, variable2 as name2, name3 };\nexport { variable1 as \"string name\" };\nexport { name1 as default, name2 };\n\n// Default exports\nexport default expression;\nexport default function functionName() { /* … */ }\nexport default class ClassName { /* … */ }\nexport default function* generatorFunctionName() { /* … */ }\nexport default function () { /* … */ }\nexport default class { /* … */ }\nexport default function* () { /* … */ }\n\n// Aggregating modules\nexport * from \"module-name\";\nexport * as name1 from \"module-name\";\nexport { name1, name2, name3 } from \"module-name\";\nexport { import1 as name1, import2 as name2, name3 } from \"module-name\";\nexport { default, import1 } from \"module-name\";\nexport { default as name1 } from \"module-name\";\n```","ref":"javascript.html#javascript-code-example"},{"type":"extras","title":"latex","doc":"","ref":"latex.html"},{"type":"extras","title":"LaTeX Code Example - latex","doc":"```latex\n\\documentclass[12pt,a4paper]{article}\n\n% Commonly used packages\n\\usepackage{amsmath,amsthm,amssymb}  % Math packages\n\\usepackage{graphicx}                % For images\n\\usepackage{hyperref}                % For hyperlinks\n\\usepackage{listings}                % For code listings\n\\usepackage{tikz}                    % For drawings\n\\usepackage{xcolor}                  % For colors\n\\usepackage{multirow}                % For complex tables\n\\usepackage{lipsum}                  % For dummy text\n\n\\title{\\textbf{LaTeX Features Demonstration}}\n\\author{Your Name}\n\\date{\\today}\n\n% Custom theorem environments\n\\newtheorem{theorem}{Theorem}[section]\n\\newtheorem{lemma}[theorem]{Lemma}\n\\newtheorem{definition}{Definition}[section]\n\n% Custom commands\n\\newcommand{\\R}{\\mathbb{R}}\n\\newcommand{\\norm}[1]{\\left\\|#1\\right\\|}\n\n\\begin{document}\n\n\\maketitle\n\\tableofcontents\n\n\\section{Mathematical Expressions}\n\n\\subsection{Inline Math}\nThe quadratic formula is $x = \\frac{-b \\pm \\sqrt{b^2 - 4ac}}{2a}$. \nLet's also show a set: $S = \\{x \\in \\R : x^2 < 4\\}$.\n\n\\subsection{Display Math}\nHere's a beautiful equation:\n\\[\n    \\oint_C \\vec{F} \\cdot d\\vec{r} = \\iint_S (\\nabla \\times \\vec{F}) \\cdot d\\vec{S}\n\\]\n\nMatrix representation:\n\\[\nA = \\begin{bmatrix}\n    1 & 2 & 3 \\\\\n    4 & 5 & 6 \\\\\n    7 & 8 & 9\n\\end{bmatrix}\n\\]\n\n\\subsection{Aligned Equations}\n\\begin{align}\n    (a + b)^2 &= (a + b)(a + b) \\\\\n    &= a^2 + ab + ba + b^2 \\\\\n    &= a^2 + 2ab + b^2\n\\end{align}\n\n\\section{Theorems and Proofs}\n\n\\begin{theorem}\n    For any triangle, the sum of interior angles is 180°.\n\\end{theorem}\n\n\\begin{proof}\n    This is a sample proof. \\qed\n\\end{proof}\n\n\\begin{lemma}\n    If $a|b$ and $b|c$, then $a|c$.\n\\end{lemma}\n\n\\section{Lists and Enumerations}\n\n\\subsection{Bullet Points}\n\\begin{itemize}\n    \\item First item\n    \\item Second item\n        \\begin{itemize}\n            \\item Nested item 1\n            \\item Nested item 2\n        \\end{itemize}\n    \\item Third item\n\\end{itemize}\n\n\\subsection{Numbered List}\n\\begin{enumerate}\n    \\item First step\n    \\item Second step\n        \\begin{enumerate}[a)]\n            \\item Sub-step a\n            \\item Sub-step b\n        \\end{enumerate}\n    \\item Third step\n\\end{enumerate}\n\n\\section{Tables}\n\n\\begin{table}[h]\n\\centering\n\\begin{tabular}{|c|c|c|}\n    \\hline\n    \\multirow{2}{*}{Item} & \\multicolumn{2}{c|}{Values} \\\\\n    \\cline{2-3}\n    & First & Second \\\\\n    \\hline\n    A & 1 & 2 \\\\\n    B & 3 & 4 \\\\\n    \\hline\n\\end{tabular}\n\\caption{Sample Table}\n\\label{tab:sample}\n\\end{table}\n\n\\section{Code Listings}\n\n\\begin{lstlisting}[language=Python]\ndef fibonacci(n):\n    if n <= 1:\n        return n\n    return fibonacci(n-1) + fibonacci(n-2)\n\\end{lstlisting}\n\n\\section{Graphics with TikZ}\n\n\\begin{tikzpicture}\n\\draw[thick,->] (0,0) -- (4,0) node[right]{$x$};\n\\draw[thick,->] (0,0) -- (0,4) node[above]{$y$};\n\\draw[blue] (0,0) circle (1cm);\n\\end{tikzpicture}\n\n\\section{References and Citations}\n\n\\begin{thebibliography}{9}\n\\bibitem{latex2e}\n  Leslie Lamport,\n  \\emph{LaTeX: A Document Preparation System},\n  Addison-Wesley, 1994.\n\\end{thebibliography}\n\nAs discussed in \\cite{latex2e}, LaTeX is powerful.\n\n\\appendix\n\\section{Additional Notes}\n\n\\lipsum[1]  % Generates dummy text\n\n\\end{document}\n```","ref":"latex.html#latex-code-example"},{"type":"extras","title":"makefile","doc":"","ref":"makefile.html"},{"type":"extras","title":"Makefile Code Example - makefile","doc":"```makefile\n# This is a demo Makefile showcasing various features and syntax\n\n# Variables and assignments\n# := is immediate assignment\nCC := gcc\n# = is recursive assignment\nCFLAGS = -Wall -O2\n# ?= assigns only if variable is not already set\nDEBUG ?= 0\n# += appends to existing variable\nCFLAGS += -g\n\n# Special variables\n.DEFAULT_GOAL := all\n.PHONY: all clean test\n\n# Shell commands in variables\nCURRENT_DIR := $(shell pwd)\nFILES := $(shell ls *.c 2>/dev/null)\n\n# Pattern substitution\nSOURCES := foo.c bar.c baz.c\nOBJECTS := $(SOURCES:.c=.o)\nHEADERS := $(wildcard *.h)\n\n# Conditional directives\nifeq ($(DEBUG), 1)\n    CFLAGS += -DDEBUG -g\nelse\n    CFLAGS += -DNDEBUG\nendif\n\n# Define colors for output\nBLUE := \\033[34m\nRESET := \\033[0m\n\n# Multi-line variable definition with define\ndefine HELP_TEXT\nAvailable targets:\n  all    : Build everything\n  clean  : Remove generated files\n  test   : Run tests\n  help   : Show this help message\nendef\nexport HELP_TEXT\n\n# Default target\nall: prepare $(OBJECTS)\n    @echo \"Building all targets...\"\n    $(CC) $(CFLAGS) -o program $(OBJECTS)\n\n# Pattern rule for object files\n%.o: %.c %.h\n    @echo \"$(BLUE)Compiling $<$(RESET)\"\n    @$(CC) $(CFLAGS) -c $< -o $@\n\n# Static pattern rules\n$(OBJECTS): %.o: %.c\n    $(CC) $(CFLAGS) -c $< -o $@\n\n# Target with multiple prerequisites\nprepare: check-env create-dirs\n    @echo \"Preparation complete\"\n\n# Silent target (using @)\ncreate-dirs:\n    @mkdir -p build\n    @mkdir -p dist\n\n# Target with order-only prerequisites (after |)\ndist/program: program | dist\n    cp program dist/\n\n# Using automatic variables\ncheck-env:\n    @echo \"Current directory: $(@D)\"\n    @echo \"Target name: $@\"\n    @echo \"First prerequisite: $<\"\n\n# Target-specific variable\ntest: CFLAGS += -DTESTING\ntest: $(OBJECTS)\n    @echo \"Running tests with $(CFLAGS)\"\n\n# Include other makefiles\n-include config.mk\n\n# Using filter and filter-out\nFILTER_EXAMPLE := $(filter %.c,$(FILES))\nFILTER_OUT_EXAMPLE := $(filter-out main.c,$(SOURCES))\n\n# Using foreach\npaths := $(foreach file,$(FILES),$(CURRENT_DIR)/$(file))\n\n# Clean target with wildcard\nclean:\n    @echo \"Cleaning up...\"\n    -rm -f *.o program\n    -rm -rf build dist\n\n# Help target\nhelp:\n    @echo \"$$HELP_TEXT\"\n\n# Error handling\ncheck-compiler:\n    @command -v $(CC) >/dev/null 2>&1 || \\\n        { echo \"Error: $(CC) not found\"; exit 1; }\n\n# Secondary expansion example\n.SECONDEXPANSION:\nSECONDARY_DEPS = $(OBJECTS:.o=.d)\n%.d: $$(%.o)\n    @echo \"Generating dependencies for $<\"\n\n# Grouped targets\n.PHONY: build-all\nbuild-all: lib app docs\n\n# Pattern rules with multiple targets\n%.pdf %.html: %.md\n    pandoc $< -o $@\n\n# Silent recipe execution\n.SILENT: clean\n\n# Parallel execution control\n.NOTPARALLEL: critical-section\n\n# Default pattern rule\n%: %.c\n    $(CC) $(CFLAGS) $< -o $@\n```","ref":"makefile.html#makefile-code-example"},{"type":"extras","title":"python","doc":"","ref":"python.html"},{"type":"extras","title":"Python Code Example - python","doc":"```python\n# This is a comprehensive Python syntax demo\nfrom typing import List, Dict, Optional, Union, Callable\nfrom dataclasses import dataclass\nfrom enum import Enum\nimport asyncio\nfrom contextlib import contextmanager\n\n# Enums\nclass Color(Enum):\n    RED = 1\n    GREEN = 2\n    BLUE = 3\n\n# Dataclass\n@dataclass\nclass Point:\n    x: float\n    y: float\n\n    def __add__(self, other):\n        return Point(self.x + other.x, self.y + other.y)\n\n# Type hints and function annotations\ndef calculate_average(numbers: List[float]) -> float:\n    \"\"\"\n    Docstring: Calculate average of numbers\n    Args:\n        numbers: List of numbers\n    Returns:\n        Average value\n    \"\"\"\n    return sum(numbers) / len(numbers)\n\n# Lambda functions\nsquare = lambda x: x ** 2\n\n# List comprehension\nsquares = [x**2 for x in range(10)]\n\n# Dictionary comprehension\nsquare_dict = {x: x**2 for x in range(5)}\n\n# Set comprehension\neven_squares = {x**2 for x in range(10) if x % 2 == 0}\n\n# Generator expression\ngen = (x**2 for x in range(10))\n\n# Context manager\n@contextmanager\ndef managed_resource():\n    print(\"Entering context\")\n    try:\n        yield \"resource\"\n    finally:\n        print(\"Exiting context\")\n\n# Decorator\ndef timer(func):\n    def wrapper(*args, **kwargs):\n        from time import time\n        start = time()\n        result = func(*args, **kwargs)\n        print(f\"Function {func.__name__} took {time() - start:.2f} seconds\")\n        return result\n    return wrapper\n\n# Class inheritance and magic methods\nclass Shape:\n    def __init__(self, name: str):\n        self.name = name\n\n    @property\n    def description(self) -> str:\n        return f\"I am a {self.name}\"\n\nclass Circle(Shape):\n    def __init__(self, radius: float):\n        super().__init__(\"circle\")\n        self.radius = radius\n\n    def __str__(self) -> str:\n        return f\"Circle(radius={self.radius})\"\n\n# Async/await syntax\nasync def async_function():\n    await asyncio.sleep(1)\n    return \"async result\"\n\n# Error handling\ndef divide(a: float, b: float) -> float:\n    try:\n        return a / b\n    except ZeroDivisionError:\n        raise ValueError(\"Cannot divide by zero\")\n    finally:\n        print(\"Division attempted\")\n\n# Match statement (Python 3.10+)\ndef match_example(value):\n    match value:\n        case str():\n            return \"It's a string\"\n        case int() | float():\n            return \"It's a number\"\n        case list():\n            return \"It's a list\"\n        case _:\n            return \"Unknown type\"\n\n# Type Union and Optional\ndef process_data(data: Union[str, int], default: Optional[str] = None) -> str:\n    if isinstance(data, int):\n        return str(data)\n    return data or default or \"\"\n\n# Main execution\nif __name__ == \"__main__\":\n    # Dictionary unpacking\n    dict1 = {\"a\": 1, \"b\": 2}\n    dict2 = {\"c\": 3, **dict1}\n\n    # List unpacking\n    numbers = [1, 2, 3]\n    first, *rest = numbers\n\n    # Using context manager\n    with managed_resource() as resource:\n        print(f\"Using {resource}\")\n\n    # Async execution\n    async def main():\n        result = await async_function()\n        print(result)\n\n    asyncio.run(main())\n\n    # Demonstrating type hints\n    point1 = Point(1.0, 2.0)\n    point2 = Point(3.0, 4.0)\n    point3 = point1 + point2\n\n    # Using match statement\n    print(match_example(\"test\"))\n    print(match_example(42))\n\n    # Using walrus operator (Python 3.8+)\n    if (n := len(numbers)) > 2:\n        print(f\"List has {n} items\")\n```","ref":"python.html#python-code-example"},{"type":"extras","title":"ruby","doc":"","ref":"ruby.html"},{"type":"extras","title":"Ruby Code Example - ruby","doc":"```ruby\n#!/usr/bin/env ruby\n\n# Frozen string literal comment (Ruby 3.0+)\n# frozen_string_literal: true\n\n# Module definition with mixin functionality\nmodule Greetable\n  def greet\n    \"Hello, #{@name}!\"\n  end\nend\n\n# Class definition with inheritance\nclass Animal\n  attr_accessor :name  # Attribute accessor\n\n  # Class variable\n  @@count = 0\n\n  # Constructor\n  def initialize(name)\n    @name = name       # Instance variable\n    @@count += 1\n  end\n\n  # Class method\n  def self.count\n    @@count\n  end\n\n  # Instance method\n  def speak\n    raise NotImplementedError, \"Subclass must implement abstract method\"\n  end\nend\n\n# Inheritance and module inclusion\nclass Dog  (name) { \"Hello, #{name}!\" }\n  puts greeter.call(\"World\")\n\n  # Proc definition\n  multiplier = proc { |x| x * 2 }\n  puts [1, 2, 3].map(&multiplier)\n\n  # Conditional expressions\n  puts \"It's sunny!\" if Time.now.hour > 6\n\n  # Unless statement\n  puts \"Good night!\" unless Time.now.hour < 20\n\n  # Ternary operator\n  status = dog.name.empty? ? \"Anonymous\" : dog.name\n\n  # Method with keyword arguments\n  def configure(host: \"localhost\", port: 8080)\n    \"Configured with #{host}:#{port}\"\n  end\n\n  # Splat operator for arrays\n  def sum(*numbers)\n    numbers.reduce(0, :+)\n  end\n\n  puts sum(1, 2, 3, 4, 5)\n\n  # Double splat operator for hashes\n  def settings(**options)\n    options\n  end\n\n  # Parallel assignment\n  a, b = 1, 2\n\n  # Safe navigation operator\n  user = nil\n  puts user&.name\n\n  # Here document\n  message = <<~HEREDOC\n    This is a multi-line\n    string using HEREDOC\n    syntax\n  HEREDOC\n\nrescue StandardError => e\n  puts \"Error: #{e.message}\"\nensure\n  puts \"Execution completed\"\nend\n\n# Freeze object\nCONSTANTS = %w[ONE TWO THREE].freeze\n\n# Method access control\nclass Example\n  def public_method\n    \"Public\"\n  end\n\n  private\n\n  def private_method\n    \"Private\"\n  end\n\n  protected\n\n  def protected_method\n    \"Protected\"\n  end\nend\n```","ref":"ruby.html#ruby-code-example"},{"type":"extras","title":"rust","doc":"","ref":"rust.html"},{"type":"extras","title":"Rust Code Example - rust","doc":"```rust\nuse std::fs::{File, OpenOptions};\nuse std::io::{self, Write, Read};\nuse std::path::Path;\n\nfn main() -> io::Result<()> {\n    // File creation and writing\n    let mut file = File::create(\"demo.txt\")?;\n    writeln!(file, \"Hello, Rust!\")?;\n\n    // Append mode demonstration\n    let mut append_file = OpenOptions::new()\n        .append(true)\n        .open(\"demo.txt\")?;\n    writeln!(append_file, \"Appending new content\")?;\n\n    // Reading file contents\n    let mut content = String::new();\n    let mut read_file = File::open(\"demo.txt\")?;\n    read_file.read_to_string(&mut content)?;\n    println!(\"File contents: {}\", content);\n\n    // Check if file exists\n    let path = Path::new(\"demo.txt\");\n    if path.exists() {\n        println!(\"File exists!\");\n    }\n\n    // Writing binary data\n    let bytes = [65, 66, 67]; // ABC in ASCII\n    file.write_all(&bytes)?;\n\n    // Buffer writing\n    let mut buffer = io::BufWriter::new(file);\n    buffer.write_all(b\"Buffered write\")?;\n    buffer.flush()?;\n\n    Ok(())\n}\n```","ref":"rust.html#rust-code-example"},{"type":"extras","title":"sql","doc":"","ref":"sql.html"},{"type":"extras","title":"SQL Code Example - sql","doc":"```sql\n-- This is a comprehensive SQL demo file showcasing various features\n-- Comments can be written with double dashes\n\n/*\nMulti-line comments\ncan be written this way\n*/\n\n-- Database Creation\nCREATE DATABASE demo_database;\nUSE demo_database;\n\n-- Table Creation with Various Data Types and Constraints\nCREATE TABLE employees (\n    employee_id INT PRIMARY KEY AUTO_INCREMENT,\n    first_name VARCHAR(50) NOT NULL,\n    last_name VARCHAR(50) NOT NULL,\n    email VARCHAR(100) UNIQUE,\n    hire_date DATE DEFAULT CURRENT_DATE,\n    salary DECIMAL(10,2) CHECK (salary >= 0),\n    department_id INT,\n    status ENUM('active', 'inactive', 'on_leave'),\n    last_updated TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP\n);\n\nCREATE TABLE departments (\n    department_id INT PRIMARY KEY,\n    name VARCHAR(100) NOT NULL,\n    budget DECIMAL(15,2),\n    CONSTRAINT positive_budget CHECK (budget > 0)\n);\n\n-- Adding Foreign Key Constraint\nALTER TABLE employees\nADD CONSTRAINT fk_department\nFOREIGN KEY (department_id) REFERENCES departments(department_id)\nON DELETE SET NULL\nON UPDATE CASCADE;\n\n-- Creating an Index\nCREATE INDEX idx_employee_name \nON employees(last_name, first_name);\n\n-- Inserting Data with Different Methods\nINSERT INTO departments VALUES \n(1, 'Engineering', 1000000.00),\n(2, 'Marketing', 500000.00),\n(3, 'Sales', 750000.00);\n\nINSERT INTO employees \n(first_name, last_name, email, salary, department_id, status)\nVALUES \n('John', 'Doe', 'john.doe@example.com', 75000.00, 1, 'active'),\n('Jane', 'Smith', 'jane.smith@example.com', 82000.00, 2, 'active');\n\n-- Updating Data\nUPDATE employees \nSET salary = salary * 1.1\nWHERE department_id = 1 \nAND YEAR(hire_date)   (\n    SELECT AVG(salary) \n    FROM employees \n    WHERE department_id = e.department_id\n)\nORDER BY e.salary DESC;\n\n-- Common Table Expression (CTE)\nWITH dept_stats AS (\n    SELECT \n        department_id,\n        COUNT(*) as emp_count,\n        AVG(salary) as avg_salary\n    FROM employees\n    GROUP BY department_id\n)\nSELECT \n    d.name,\n    ds.emp_count,\n    ds.avg_salary\nFROM dept_stats ds\nJOIN departments d ON ds.department_id = d.department_id;\n\n-- Window Functions\nSELECT \n    first_name,\n    last_name,\n    salary,\n    department_id,\n    RANK() OVER (PARTITION BY department_id ORDER BY salary DESC) as salary_rank,\n    AVG(salary) OVER (PARTITION BY department_id) as dept_avg_salary\nFROM employees;\n\n-- Creating a View\nCREATE VIEW employee_summary AS\nSELECT \n    e.employee_id,\n    CONCAT(e.first_name, ' ', e.last_name) as full_name,\n    d.name as department,\n    e.salary\nFROM employees e\nLEFT JOIN departments d ON e.department_id = d.department_id;\n\n-- Creating a Stored Procedure\nDELIMITER //\nCREATE PROCEDURE give_raise(\n    IN emp_id INT,\n    IN raise_percentage DECIMAL(5,2)\n)\nBEGIN\n    UPDATE employees\n    SET salary = salary * (1 + raise_percentage/100)\n    WHERE employee_id = emp_id;\nEND //\nDELIMITER ;\n\n-- Creating a Trigger\nCREATE TRIGGER before_employee_update\nBEFORE UPDATE ON employees\nFOR EACH ROW\nBEGIN\n    IF NEW.salary < OLD.salary THEN\n        SIGNAL SQLSTATE '45000'\n        SET MESSAGE_TEXT = 'Salary cannot be decreased';\n    END IF;\nEND;\n\n-- Example of CASE statement in SELECT\nSELECT \n    first_name,\n    last_name,\n    salary,\n    CASE \n        WHEN salary < 50000 THEN 'Entry Level'\n        WHEN salary BETWEEN 50000 AND 100000 THEN 'Mid Level'\n        ELSE 'Senior Level'\n    END as salary_bracket\nFROM employees;\n\n-- Cleanup (if needed)\n-- DROP VIEW employee_summary;\n-- DROP PROCEDURE give_raise;\n-- DROP TRIGGER before_employee_update;\n-- DROP TABLE employees;\n-- DROP TABLE departments;\n-- DROP DATABASE demo_database;\n```","ref":"sql.html#sql-code-example"},{"type":"extras","title":"typescript","doc":"","ref":"typescript.html"},{"type":"extras","title":"TypeScript Code Example - typescript","doc":"```typescript\n// Basic Types and Type Annotations\nlet isDone: boolean = false;\nlet decimal: number = 6;\nlet color: string = \"blue\";\nlet list: number[] = [1, 2, 3];\nlet tuple: [string, number] = [\"hello\", 10];\n\n// Enum\nenum Direction {\n    Up = \"UP\",\n    Down = \"DOWN\",\n    Left = \"LEFT\",\n    Right = \"RIGHT\"\n}\n\n// Interface\ninterface User {\n    readonly id: number;\n    name: string;\n    age?: number;  // Optional property\n    [key: string]: any;  // Index signature\n}\n\n// Generic Interface\ninterface Response  {\n    data: T;\n    status: number;\n}\n\n// Class with implements and extends\nabstract class Animal {\n    protected name: string;\n\n    constructor(name: string) {\n        this.name = name;\n    }\n\n    abstract makeSound(): void;\n}\n\n// Interface for class implementation\ninterface Pet {\n    play(): void;\n}\n\nclass Dog extends Animal implements Pet {\n    private breed: string;\n\n    constructor(name: string, breed: string) {\n        super(name);\n        this.breed = breed;\n    }\n\n    makeSound(): void {\n        console.log(\"Woof!\");\n    }\n\n    play(): void {\n        console.log(`${this.name} is playing!`);\n    }\n}\n\n// Union Types\ntype StringOrNumber = string | number;\nlet flexible: StringOrNumber = \"hello\";\nflexible = 42;\n\n// Intersection Types\ntype Employee = User & { employeeId: number };\n\n// Utility Types\ntype Readonly  = {\n    readonly [P in keyof T]: T[P];\n}\n\n// Type Guards\nfunction isString(value: any): value is string {\n    return typeof value === \"string\";\n}\n\n// Generics\nfunction identity (arg: T): T {\n    return arg;\n}\n\n// Generic Constraints\ninterface Lengthwise {\n    length: number;\n}\n\nfunction loggingIdentity (arg: T): T {\n    console.log(arg.length);\n    return arg;\n}\n\n// Mapped Types\ntype Optional  = {\n    [P in keyof T]?: T[P];\n}\n\n// Conditional Types\ntype NonNullable  = T extends null | undefined ? never : T;\n\n// Template Literal Types\ntype EventName = `on${string}`;\ntype Size = 'small' | 'medium' | 'large';\ntype Color = 'red' | 'blue' | 'green';\ntype StyleVariant = `${Size}-${Color}`;\n\n// Decorators\nfunction log(target: any, propertyKey: string) {\n    console.log(`${propertyKey} accessed`);\n}\n\n// Async/Await with TypeScript\nasync function fetchData (url: string): Promise  {\n    const response = await fetch(url);\n    return response.json();\n}\n\n// Type Assertions\nlet someValue: unknown = \"this is a string\";\nlet strLength: number = (someValue as string).length;\n\n// Literal Types\ntype DiceRoll = 1 | 2 | 3 | 4 | 5 | 6;\nlet diceResult: DiceRoll = 1;\n\n// Function Overloads\nfunction process(x: number): number;\nfunction process(x: string): string;\nfunction process(x: number | string): number | string {\n    return x;\n}\n\n// Namespace\nnamespace Validation {\n    export interface StringValidator {\n        isValid(s: string): boolean;\n    }\n}\n\n// Example Usage\nconst user: User = {\n    id: 1,\n    name: \"John\",\n    customField: \"value\"\n};\n\nconst dog = new Dog(\"Rex\", \"Golden Retriever\");\nconst numberIdentity = identity (42);\nconst response: Response  = {\n    data: \"Success\",\n    status: 200\n};\n\n// Type Inference\nlet inferredArray = [1, 2, 3]; // Type is number[]\nlet inferredObject = { x: 10, y: 20 }; // Type is { x: number, y: number }\n\n// Readonly Arrays\nconst readonlyNumbers: ReadonlyArray  = [1, 2, 3];\n\n// Index Types\nfunction getProperty (obj: T, key: K): T[K] {\n    return obj[key];\n}\n```","ref":"typescript.html#typescript-code-example"},{"type":"extras","title":"xml","doc":"","ref":"xml.html"},{"type":"extras","title":"XML Code Example - xml","doc":"```xml\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<!-- This is an XML comment -->\n<!DOCTYPE library [\n  <!ELEMENT library (book+)>\n  <!ELEMENT book (title, author+, published, description?)>\n  <!ELEMENT title (#PCDATA)>\n  <!ELEMENT author (#PCDATA)>\n  <!ELEMENT published (#PCDATA)>\n  <!ELEMENT description (#PCDATA)>\n  <!ATTLIST book \n    id ID #REQUIRED\n    category CDATA #IMPLIED\n    inStock (yes|no) \"yes\">\n]>\n\n \n  \n  <!-- Basic element with attributes -->\n   \n     The Great Gatsby \n    <!-- Multiple elements of same type -->\n     F. Scott Fitzgerald \n     1925 \n    <!-- CDATA section for text with special characters -->\n     <![CDATA[A story about the American Dream & society in the 1920s]]> \n   \n\n  <!-- Namespaces -->\n   \n     1984 \n     George Orwell \n    <!-- Empty element -->\n     \n   \n\n  <!-- Special characters and entities -->\n   \n     Alice &amp; Wonderland \n     Lewis Carroll \n     1865 \n    <!-- Mixed content -->\n     \n      A tale about a girl named  Alice  who falls down a rabbit hole.\n      Special chars: &lt; &gt; &amp; &apos; &quot;\n     \n   \n\n  <!-- Processing instruction -->\n  <?display-mode full-screen?>\n  \n  <!-- Whitespace preservation -->\n   \n         The    Raven     \n     Edgar Allan Poe \n     1845 \n   \n \n```","ref":"xml.html#xml-code-example"},{"type":"extras","title":"zig","doc":"","ref":"zig.html"},{"type":"extras","title":"Zig Code Example - zig","doc":"```zig\n// Single line comment\n/// Doc comment for documentation generation\n\n// Import standard library\nconst std = @import(\"std\");\n\n// Declare constants\nconst MY_CONSTANT: i32 = 42;\nconst PI = 3.14159;\n\n// Declare an enum\nconst Direction = enum {\n    north,\n    south,\n    east,\n    west,\n\n    // Enum with method\n    pub fn isVertical(self: Direction) bool {\n        return self == .north or self == .south;\n    }\n};\n\n// Define a struct\nconst Person = struct {\n    name: []const u8,\n    age: u8,\n    height: f32,\n\n    // Method definition\n    pub fn introduce(self: Person) void {\n        std.debug.print(\"Hi, I'm {s}, {d} years old\\n\", .{\n            self.name,\n            self.age,\n        });\n    }\n};\n\n// Error set definition\nconst MathError = error{\n    DivisionByZero,\n    Overflow,\n};\n\n// Union type\nconst Value = union(enum) {\n    integer: i64,\n    float: f64,\n    boolean: bool,\n};\n\n// Main function\npub fn main() !void {\n    // Variables\n    var mutable_var: i32 = 100;\n    const immutable_var = @as(i32, 200);\n\n    // Array\n    var array = [_]i32{ 1, 2, 3, 4, 5 };\n\n    // Slice\n    const slice = array[1..3];\n\n    // String literal\n    const greeting = \"Hello, Zig!\";\n\n    // Optional type\n    var optional_value: ?i32 = null;\n    optional_value = 42;\n\n    // Error union type\n    var result: MathError!i32 = undefined;\n\n    // If statement\n    if (mutable_var > 50) {\n        std.debug.print(\"Greater than 50\\n\", .{});\n    } else {\n        std.debug.print(\"Less than or equal to 50\\n\", .{});\n    }\n\n    // Switch statement\n    const direction = Direction.north;\n    switch (direction) {\n        .north => std.debug.print(\"Going north\\n\", .{}),\n        .south => std.debug.print(\"Going south\\n\", .{}),\n        else => std.debug.print(\"Going east or west\\n\", .{}),\n    }\n\n    // While loop\n    var i: usize = 0;\n    while (i < 5) : (i += 1) {\n        if (i == 2) continue;\n        if (i == 4) break;\n        std.debug.print(\"{d}\\n\", .{i});\n    }\n\n    // For loop\n    for (array, 0..) |value, index| {\n        std.debug.print(\"Index: {d}, Value: {d}\\n\", .{ index, value });\n    }\n\n    // Error handling\n    result = divide(10, 2) catch |err| {\n        std.debug.print(\"Error: {}\\n\", .{err});\n        return err;\n    };\n\n    // Defer statement\n    {\n        const file = std.fs.cwd().createFile(\n            \"test.txt\",\n            .{ .read = true },\n        ) catch |err| {\n            std.debug.print(\"Could not create file: {}\\n\", .{err});\n            return;\n        };\n        defer file.close();\n    }\n\n    // Allocator example\n    var gpa = std.heap.GeneralPurposeAllocator(.{}){};\n    defer _ = gpa.deinit();\n    const allocator = gpa.allocator();\n\n    // Dynamic array (ArrayList)\n    var list = std.ArrayList(i32).init(allocator);\n    defer list.deinit();\n    try list.append(42);\n\n    // Comptime\n    const compiled_value = comptime blk: {\n        var x: i32 = 1;\n        x += 2;\n        break :blk x;\n    };\n\n    // Testing\n    if (std.builtin.is_test) {\n        try std.testing.expect(compiled_value == 3);\n    }\n}\n\n// Function with error handling\nfn divide(a: i32, b: i32) MathError!i32 {\n    if (b == 0) return MathError.DivisionByZero;\n    return a / b;\n}\n\n// Test function\ntest \"basic test\" {\n    try std.testing.expect(MY_CONSTANT == 42);\n}\n```","ref":"zig.html#zig-code-example"},{"type":"extras","title":"MakeupSyntect","doc":"# MakeupSyntect\n\nLexes code for Elixir's Makeup project using the [syntect](https://docs.rs/syntect/latest/syntect/) Rust library.\nMore syntax definitions are included from [two-face](https://docs.rs/two-face/latest/two_face/).\n\nAt the moment, 205 different syntaxes are supported. For a list of supported languages, see [the documentation](https://hexdocs.pm/makeup_syntect/MakeupSyntect.Syntaxes.html).\n\nMakeupSyntect automatically registers those syntaxes in Makeup's registry (exceptions see below),\nwhich allows them to be used in ExDoc and other projects using Makeup. The name to use when writing\nmarkdown code blocks in ExDoc is shown in brackets in the `MakeupSyntect.Syntaxes` module documentation.\n\nNote that by default, the following syntaxes are disabled, as the existing Makeup lexers are considered to be better:\n\n* `\"elixir\"`\n* `\"erlang\"`\n* `\"html_eex\"`\n\nWe recommend you to use the `:makeup_elixir` / `:makeup_erlang` / `:makeup_eex` packages instead.\n\nTo configure which languages to register for, the `:register_for_languages` and `:excluded_languages` configurations can be used.:\n\n```elixir\nconfig :makeup_syntect,\n  register_for_languages: [\"rust\", \"toml\"], # default: :all\n  excluded_languages: []                    # default: [\"elixir\", \"erlang\", \"html_eex\"]\n```","ref":"readme.html"},{"type":"extras","title":"Installation - MakeupSyntect","doc":"The package can be installed by adding `makeup_syntect` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:makeup_syntect, github: \"SteffenDE/makeup_syntect\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.0"}}